==> kubernetes-model-autoscaling-6.3.0-sources.jar: io/fabric8/kubernetes/api/model/autoscaling/v2/HorizontalPodAutoscalerBehaviorFluent.java <==
package io.fabric8.kubernetes.api.model.autoscaling.v2;

import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface HorizontalPodAutoscalerBehaviorFluent<A extends HorizontalPodAutoscalerBehaviorFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildScaleDown instead.
   * @return The buildable object.
   */
  @Deprecated
  public HPAScalingRules getScaleDown();
  public HPAScalingRules buildScaleDown();
  public A withScaleDown(HPAScalingRules scaleDown);
  public Boolean hasScaleDown();
  public HorizontalPodAutoscalerBehaviorFluent.ScaleDownNested<A> withNewScaleDown();
  public HorizontalPodAutoscalerBehaviorFluent.ScaleDownNested<A> withNewScaleDownLike(HPAScalingRules item);
  public HorizontalPodAutoscalerBehaviorFluent.ScaleDownNested<A> editScaleDown();
  public HorizontalPodAutoscalerBehaviorFluent.ScaleDownNested<A> editOrNewScaleDown();
  public HorizontalPodAutoscalerBehaviorFluent.ScaleDownNested<A> editOrNewScaleDownLike(HPAScalingRules item);
  
  /**
   * This method has been deprecated, please use method buildScaleUp instead.
   * @return The buildable object.
   */
  @Deprecated
  public HPAScalingRules getScaleUp();
  public HPAScalingRules buildScaleUp();
  public A withScaleUp(HPAScalingRules scaleUp);
  public Boolean hasScaleUp();
  public HorizontalPodAutoscalerBehaviorFluent.ScaleUpNested<A> withNewScaleUp();
  public HorizontalPodAutoscalerBehaviorFluent.ScaleUpNested<A> withNewScaleUpLike(HPAScalingRules item);
  public HorizontalPodAutoscalerBehaviorFluent.ScaleUpNested<A> editScaleUp();
  public HorizontalPodAutoscalerBehaviorFluent.ScaleUpNested<A> editOrNewScaleUp();
  public HorizontalPodAutoscalerBehaviorFluent.ScaleUpNested<A> editOrNewScaleUpLike(HPAScalingRules item);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface ScaleDownNested<N> extends Nested<N>,HPAScalingRulesFluent<HorizontalPodAutoscalerBehaviorFluent.ScaleDownNested<N>>{
    public N and();
    public N endScaleDown();
    
  }
  public interface ScaleUpNested<N> extends Nested<N>,HPAScalingRulesFluent<HorizontalPodAutoscalerBehaviorFluent.ScaleUpNested<N>>{
    public N and();
    public N endScaleUp();
    
  }
  
}

==> kubernetes-model-autoscaling-6.7.2-sources.jar: io/fabric8/kubernetes/api/model/autoscaling/v2/HorizontalPodAutoscalerBehaviorFluent.java <==
package io.fabric8.kubernetes.api.model.autoscaling.v2;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface HorizontalPodAutoscalerBehaviorFluent<A extends HorizontalPodAutoscalerBehaviorFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildScaleDown instead.
   * @return The buildable object.
   */
  @Deprecated
  public HPAScalingRules getScaleDown();
  public HPAScalingRules buildScaleDown();
  public A withScaleDown(HPAScalingRules scaleDown);
  public Boolean hasScaleDown();
  public HorizontalPodAutoscalerBehaviorFluent.ScaleDownNested<A> withNewScaleDown();
  public HorizontalPodAutoscalerBehaviorFluent.ScaleDownNested<A> withNewScaleDownLike(HPAScalingRules item);
  public HorizontalPodAutoscalerBehaviorFluent.ScaleDownNested<A> editScaleDown();
  public HorizontalPodAutoscalerBehaviorFluent.ScaleDownNested<A> editOrNewScaleDown();
  public HorizontalPodAutoscalerBehaviorFluent.ScaleDownNested<A> editOrNewScaleDownLike(HPAScalingRules item);
  
  /**
   * This method has been deprecated, please use method buildScaleUp instead.
   * @return The buildable object.
   */
  @Deprecated
  public HPAScalingRules getScaleUp();
  public HPAScalingRules buildScaleUp();
  public A withScaleUp(HPAScalingRules scaleUp);
  public Boolean hasScaleUp();
  public HorizontalPodAutoscalerBehaviorFluent.ScaleUpNested<A> withNewScaleUp();
  public HorizontalPodAutoscalerBehaviorFluent.ScaleUpNested<A> withNewScaleUpLike(HPAScalingRules item);
  public HorizontalPodAutoscalerBehaviorFluent.ScaleUpNested<A> editScaleUp();
  public HorizontalPodAutoscalerBehaviorFluent.ScaleUpNested<A> editOrNewScaleUp();
  public HorizontalPodAutoscalerBehaviorFluent.ScaleUpNested<A> editOrNewScaleUpLike(HPAScalingRules item);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface ScaleDownNested<N> extends Nested<N>,HPAScalingRulesFluent<HorizontalPodAutoscalerBehaviorFluent.ScaleDownNested<N>>{
    public N and();
    public N endScaleDown();
    
  }
  public interface ScaleUpNested<N> extends Nested<N>,HPAScalingRulesFluent<HorizontalPodAutoscalerBehaviorFluent.ScaleUpNested<N>>{
    public N and();
    public N endScaleUp();
    
  }
  
}
